shamir

package module
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateShares

func GenerateShares(secret []byte, numberOfShares, threshold int) ([][]byte, error)

GenerateShares takes in a secret and splits it into n shares, not greater than 255 shares Threshold is the minimum number of shares required to reconstruct the secret

func Reconstruct

func Reconstruct(shares [][]byte) (secret []byte, err error)

Reconstruct This method takes n number of shares and reconstructs the original secret

Types

This section is empty.

Jump to