Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateShares ¶
GenerateShares takes in a secret and splits it into n shares, not greater than 255 shares Threshold is the minimum number of shares required to reconstruct the secret
func Reconstruct ¶
Reconstruct This method takes n number of shares and reconstructs the original secret
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.